@@ -9,10 +9,12 @@ from __future__ import absolute_import  # noreorder
 
 import os
 import shutil
+import tempfile
 import threading
 import warnings
 from collections import OrderedDict
 
+from pyaedt import settings
 from pyaedt.application.Design import Design
 from pyaedt.application.JobManager import update_hpc_option
 from pyaedt.generic.constants import AXIS
@@ -27,6 +29,7 @@ from pyaedt.generic.constants import GravityDirection
 from pyaedt.generic.constants import Plane
 from pyaedt.generic.general_methods import filter_tuple
 from pyaedt.generic.general_methods import generate_unique_name
+from pyaedt.generic.general_methods import open_file
 from pyaedt.generic.general_methods import pyaedt_function_handler
 from pyaedt.modules.Boundary import NativeComponentObject
 from pyaedt.modules.DesignXPloration import OptimizationSetups
@@ -1221,7 +1224,7 @@ class Analysis(Design, object):
         ...
         pyaedt info: Sweep was created correctly.
         """
-        if props == None:
+        if props is None:
             props = {}
 
         if setuptype is None:
@@ -1475,7 +1478,7 @@ class Analysis(Design, object):
         if acf_file:
             self._desktop.SetRegistryFromFile(acf_file)
             name = ""
-            with open(acf_file, "r") as f:
+            with open_file(acf_file, "r") as f:
                 lines = f.readlines()
                 for line in lines:
                     if "ConfigName" in line:
@@ -1490,8 +1493,16 @@ class Analysis(Design, object):
         elif num_gpu or num_tasks or num_cores:
             config_name = "pyaedt_config"
             source_name = os.path.join(self.pyaedt_dir, "misc", "pyaedt_local_config.acf")
-            target_name = os.path.join(self.working_directory, config_name + ".acf")
+            if settings.remote_rpc_session:
+                target_name = os.path.join(tempfile.gettempdir(), generate_unique_name("config") + ".acf")
+            else:
+                target_name = (
+                    os.path.join(self.working_directory, config_name + ".acf").replace("\\", "/")
+                    if self.working_directory[0] != "\\"
+                    else os.path.join(self.working_directory, config_name + ".acf")
+                )
             shutil.copy2(source_name, target_name)
+
             if num_cores:
                 update_hpc_option(target_name, "NumCores", num_cores, False)
             if num_gpu:
@@ -1503,6 +1514,16 @@ class Analysis(Design, object):
             if self.design_type == "Icepak":
                 use_auto_settings = False
             update_hpc_option(target_name, "UseAutoSettings", self.design_type, use_auto_settings)
+
+            if settings.remote_rpc_session:
+                remote_name = (
+                    os.path.join(self.working_directory, config_name + ".acf").replace("\\", "/")
+                    if self.working_directory[0] != "\\"
+                    else os.path.join(self.working_directory, config_name + ".acf")
+                )
+                settings.remote_rpc_session.filemanager.upload(target_name, remote_name)
+                target_name = remote_name
+
             try:
                 self._desktop.SetRegistryFromFile(target_name)
                 self.set_registry_key(r"Desktop/ActiveDSOConfigurations/" + self.design_type, config_name)
@@ -1631,20 +1652,24 @@ class Analysis(Design, object):
         project_path = self.project_path
         if not aedt_full_exe_path:
             version = self.odesktop.GetVersion()[2:6]
-            if os.path.exists(r"\\" + clustername + r"\AnsysEM\AnsysEM{}\Win64\ansysedt.exe".format(version)):
+            if version >= "22.2":
+                version_name = "v" + version.replace(".", "")
+            else:
+                version_name = "AnsysEM" + version
+            if os.path.exists(r"\\" + clustername + r"\AnsysEM\{}\Win64\ansysedt.exe".format(version_name)):
                 aedt_full_exe_path = (
-                    r"\\\\\\\\" + clustername + r"\\\\AnsysEM\\\\AnsysEM{}\\\\Win64\\\\ansysedt.exe".format(version)
+                    r"\\\\\\\\" + clustername + r"\\\\AnsysEM\\\\{}\\\\Win64\\\\ansysedt.exe".format(version_name)
                 )
-            elif os.path.exists(r"\\" + clustername + r"\AnsysEM\AnsysEM{}\Linux64\ansysedt".format(version)):
+            elif os.path.exists(r"\\" + clustername + r"\AnsysEM\{}\Linux64\ansysedt".format(version_name)):
                 aedt_full_exe_path = (
-                    r"\\\\\\\\" + clustername + r"\\\\AnsysEM\\\\AnsysEM{}\\\\Linux64\\\\ansysedt".format(version)
+                    r"\\\\\\\\" + clustername + r"\\\\AnsysEM\\\\{}\\\\Linux64\\\\ansysedt".format(version_name)
                 )
             else:
-                self.logger.error("AEDT path does not exist. Please provide a full path.")
+                self.logger.error("AEDT shared path does not exist. Please provide a full path.")
                 return False
         else:
             if not os.path.exists(aedt_full_exe_path):
-                self.logger.error("Aedt Path doesn't exists. Please provide a full path")
+                self.logger.error("AEDT shared path does not exist. Provide a full path.")
                 return False
             aedt_full_exe_path.replace("\\", "\\\\")
 
@@ -1655,8 +1680,8 @@ class Analysis(Design, object):
             setting_file = os.path.join(path_file, "..", "misc", "Job_Settings.areg")
         shutil.copy(setting_file, destination_reg)
 
-        f1 = open(destination_reg, "w")
-        with open(setting_file) as f:
+        f1 = open_file(destination_reg, "w")
+        with open_file(setting_file) as f:
             lines = f.readlines()
             for line in lines:
                 if "\\	$begin" == line[:8]:
