@@ -1,9 +1,11 @@
 from __future__ import absolute_import  # noreorder
 
 import math
+import os
 import time
 
-from pyaedt.edb_core.EDB_Data import EDBNetsData, SimulationConfiguration
+from pyaedt.edb_core.EDB_Data import EDBNetsData
+from pyaedt.edb_core.EDB_Data import SimulationConfiguration
 from pyaedt.generic.constants import CSS4_COLORS
 from pyaedt.generic.general_methods import generate_unique_name
 from pyaedt.generic.general_methods import is_ironpython
@@ -226,6 +228,12 @@ class EdbNets(object):
             If `False` the plot will be colored by layer. (default)
         outline : list, optional
             List of points of the outline to plot.
+        Returns
+        -------
+        list, str
+            list of data to be used in plot.
+            In case of remote session it will be returned a string that could be converted to list
+             using ast.literal_eval().
         """
         start_time = time.time()
         color_index = 0
@@ -243,6 +251,8 @@ class EdbNets(object):
             nets = [nets]
 
         for path in self._pedb.core_primitives.paths:
+            if path.is_void:
+                continue
             net_name = path.net_name
             layer_name = path.layer_name
             if net_name in nets and layer_name in layers:
@@ -345,7 +355,10 @@ class EdbNets(object):
                         objects_lists.append([vertices, codes, label_colors[label], "", 0.4, "path"])
         end_time = time.time() - start_time
         self._logger.info("Nets Point Generation time %s seconds", round(end_time, 3))
-        return objects_lists
+        if os.getenv("PYAEDT_SERVER_AEDT_PATH", None):
+            return str(objects_lists)
+        else:
+            return objects_lists
 
     @pyaedt_function_handler()
     def classify_nets(self, simulation_configuration_object=None):
