@@ -620,8 +620,14 @@ class BoundaryObject(BoundaryCommon, object):
                     faces_out.append(f)
             self._app.oboundary.ReassignBoundary(["Name:" + self.name, "Faces:=", faces_out])
         elif "Objects" in self.props:
+            pr = []
+            for el in self.props["Objects"]:
+                try:
+                    pr.append(self._app.modeler[el].name)
+                except (KeyError, AttributeError):
+                    pass
 
-            self._app.oboundary.ReassignBoundary(["Name:" + self.name, "Objects:=", self.props["Objects"]])
+            self._app.oboundary.ReassignBoundary(["Name:" + self.name, "Objects:=", pr])
         else:
             return False
         return True
@@ -723,6 +729,69 @@ class MaxwellParameters(BoundaryCommon, object):
         self._boundary_name = self.name
         return True
 
+    @pyaedt_function_handler()
+    def _create_matrix_reduction(self, red_type, sources, matrix_name=None, join_name=None):
+        if not matrix_name:
+            matrix_name = generate_unique_name("ReducedMatrix", n=3)
+        if not join_name:
+            join_name = generate_unique_name("Join" + red_type, n=3)
+        try:
+            self._app.o_maxwell_parameters.AddReduceOp(
+                self.name,
+                matrix_name,
+                ["NAME:" + join_name, "Type:=", "Join in " + red_type, "Sources:=", ",".join(sources)],
+            )
+            return matrix_name, join_name
+        except:
+            self._app.logger.error("Failed to create Matrix Reduction")
+            return False, False
+
+    @pyaedt_function_handler()
+    def join_series(self, sources, matrix_name=None, join_name=None):
+        """
+
+        Parameters
+        ----------
+        sources : list
+            Sources to be included in matrix reduction.
+        matrix_name :  str, optional
+            name of the string to create.
+        join_name : str, optional
+            Name of the Join operation.
+
+        Returns
+        -------
+        (str, str)
+            Matrix name and Joint name.
+
+        """
+        return self._create_matrix_reduction(
+            red_type="Series", sources=sources, matrix_name=matrix_name, join_name=join_name
+        )
+
+    @pyaedt_function_handler()
+    def join_parallel(self, sources, matrix_name=None, join_name=None):
+        """
+
+        Parameters
+        ----------
+        sources : list
+            Sources to be included in matrix reduction.
+        matrix_name :  str, optional
+            name of the string to create.
+        join_name : str, optional
+            Name of the Join operation.
+
+        Returns
+        -------
+        (str, str)
+            Matrix name and Joint name.
+
+        """
+        return self._create_matrix_reduction(
+            red_type="Parallel", sources=sources, matrix_name=matrix_name, join_name=join_name
+        )
+
 
 class FieldSetup(BoundaryCommon, object):
     """Manages Far Field and Near Field Component data and execution.
