@@ -149,8 +149,9 @@ class Layer(object):
         self.zones = []
 
     @property
-    def _oeditor(self):
-        return self._layers._oeditor
+    def oeditor(self):
+        """Oeditor Module."""
+        return self._layers.oeditor
 
     @property
     def visflag(self):
@@ -219,7 +220,7 @@ class Layer(object):
         """
         self.remove_stackup_layer()
         if self.type == "signal":
-            self._oeditor.AddStackupLayer(
+            self.oeditor.AddStackupLayer(
                 [
                     "NAME:stackup layer",
                     "Name:=",
@@ -312,7 +313,7 @@ class Layer(object):
                 ]
             )
         else:
-            self._oeditor.AddStackupLayer(
+            self.oeditor.AddStackupLayer(
                 [
                     "NAME:stackup layer",
                     "Name:=",
@@ -350,7 +351,7 @@ class Layer(object):
                     ],
                 ]
             )
-        infos = self._oeditor.GetLayerInfo(self.name)
+        infos = self.oeditor.GetLayerInfo(self.name)
         infos = [i.split(": ") for i in infos]
         infosdict = {i[0]: i[1] for i in infos}
         self.id = int(infosdict["LayerId"])
@@ -559,7 +560,7 @@ class Layer(object):
 
         >>> oEditor.ChangeLayer
         """
-        self._oeditor.ChangeLayer(self._get_layer_arg)
+        self.oeditor.ChangeLayer(self._get_layer_arg)
         return True
 
     @pyaedt_function_handler()
@@ -576,8 +577,8 @@ class Layer(object):
 
         >>> oEditor.RemoveLayer
         """
-        if self.name in self._oeditor.GetStackupLayerNames():
-            self._oeditor.RemoveLayer(self.name)
+        if self.name in self.oeditor.GetStackupLayerNames():
+            self.oeditor.RemoveLayer(self.name)
             return True
         return False
 
@@ -608,14 +609,29 @@ class Layers(object):
         self.logger = self._app.logger
 
     @property
-    def _oeditor(self):
+    def oeditor(self):
         """Editor.
 
         References
         ----------
 
         >>> oEditor = oDesign.SetActiveEditor("Layout")"""
-        return self._modeler._app._odesign.SetActiveEditor("Layout")
+        return self._modeler.oeditor
+
+    @property
+    def zones(self):
+        """List of all available zones.
+
+        Returns
+        -------
+        list
+        """
+        all_layers = list(self._modeler.oeditor.GetStackupLayerNames())
+        zones = []
+        for lay in all_layers:
+            if ";" in lay:
+                zones.append(lay.split(";")[0])
+        return list(set(zones))
 
     @property
     def LengthUnit(self):
@@ -636,7 +652,7 @@ class Layers(object):
 
         >>> oEditor.GetStackupLayerNames()
         """
-        return self._oeditor.GetStackupLayerNames()
+        return [i for i in self.oeditor.GetStackupLayerNames() if ";" not in i]
 
     @property
     def drawing_layers(self):
@@ -653,7 +669,7 @@ class Layers(object):
         >>> oEditor.GetAllLayerNames()
         """
         stackup = self.all_layers
-        return [i for i in list(self._oeditor.GetAllLayerNames()) if i not in stackup]
+        return [i for i in list(self.oeditor.GetAllLayerNames()) if i not in stackup and ";" not in i]
 
     @property
     def all_signal_layers(self):
@@ -691,7 +707,7 @@ class Layers(object):
             if layid not in self.layers:
                 self.refresh_all_layers()
             if self.layers[layid].type == "dielectric":
-                die.append(layid)
+                die.append(lay)
         return die
 
     @pyaedt_function_handler()
@@ -722,11 +738,11 @@ class Layers(object):
         int
             Number of layers in the current stackup.
         """
-        layernames = self._oeditor.GetAllLayerNames()
+        layernames = [i for i in self.oeditor.GetAllLayerNames() if ";" not in i]
         for el in layernames:
             o = Layer(self, "signal")
             o.name = el
-            infos = self._oeditor.GetLayerInfo(el)
+            infos = self.oeditor.GetLayerInfo(el)
             infos = [i.split(": ") for i in infos]
             infosdict = {i[0].strip(): i[1].strip() for i in infos}
             if infosdict["Type"] == "metalizedsignal":
@@ -856,7 +872,7 @@ class Layers(object):
         """
         if mode.lower() == "multizone":
             zones = ["NAME:Zones", "Primary"]
-            for i in range(number_zones - 1):
+            for i in range(number_zones):
                 zones.append("Zone{}".format(i + 1))
             args = ["NAME:layers", "Mode:=", "Multizone", zones, ["NAME:pps"]]
         elif mode.lower() == "overlap":
@@ -873,5 +889,5 @@ class Layers(object):
                 else:
                     v.zones = []
             args.append(v._get_layer_arg)
-        self._oeditor.ChangeLayers(args)
+        self.oeditor.ChangeLayers(args)
         return True
