@@ -15,6 +15,7 @@ from pyaedt.generic.DataHandlers import _arg2dict
 from pyaedt.generic.general_methods import _create_json_file
 from pyaedt.generic.general_methods import _retry_ntimes
 from pyaedt.generic.general_methods import generate_unique_name
+from pyaedt.generic.general_methods import open_file
 from pyaedt.generic.general_methods import pyaedt_function_handler
 from pyaedt.modules.Material import Material
 from pyaedt.modules.Material import MatProperties
@@ -127,7 +128,7 @@ class Materials(object):
         def get_mat_list(file_name):
             mats = []
             _begin_search = re.compile(r"^\$begin '(.+)'")
-            with open(file_name, "r") as aedt_fh:
+            with open_file(file_name, "r") as aedt_fh:
                 raw_lines = aedt_fh.read().splitlines()
                 for line in raw_lines:
                     b = _begin_search.search(line)
@@ -183,9 +184,9 @@ class Materials(object):
         """Get materials."""
         mats = {}
         try:
-            for ds in self._app.project_properies["AnsoftProject"]["Definitions"]["Materials"]:
+            for ds in self._app.project_properties["AnsoftProject"]["Definitions"]["Materials"]:
                 mats[ds.lower()] = Material(
-                    self, ds, self._app.project_properies["AnsoftProject"]["Definitions"]["Materials"][ds]
+                    self, ds, self._app.project_properties["AnsoftProject"]["Definitions"]["Materials"][ds]
                 )
         except:
             pass
@@ -195,11 +196,11 @@ class Materials(object):
     def _get_surface_materials(self):
         mats = {}
         try:
-            for ds in self._app.project_properies["AnsoftProject"]["Definitions"]["SurfaceMaterials"]:
+            for ds in self._app.project_properties["AnsoftProject"]["Definitions"]["SurfaceMaterials"]:
                 mats[ds.lower()] = SurfaceMaterial(
                     self,
                     ds,
-                    self._app.project_properies["AnsoftProject"]["Definitions"]["SurfaceMaterials"][ds],
+                    self._app.project_properties["AnsoftProject"]["Definitions"]["SurfaceMaterials"][ds],
                 )
         except:
             pass
@@ -711,7 +712,7 @@ class Materials(object):
             ``True`` when successful, ``False`` when failed.
 
         """
-        with open(full_json_path, "r") as json_file:
+        with open_file(full_json_path, "r") as json_file:
             data = json.load(json_file)
 
         if "datasets" in list(data.keys()):
